prettypretty
============

Prettypretty's color support is hefty enough to warrant its own subpackage with
its own :doc:`colorful documentation page <color>`. Prettypretty also comes with
a couple of demo scripts. They are much less hefty but do command :doc:`their
own documentation <tools>`


prettypretty.ansi
-----------------

.. automodule:: prettypretty.ansi
    :members:


prettypretty.darkmode
---------------------

.. automodule:: prettypretty.darkmode
    :members:


prettypretty.fidelity
---------------------

.. automodule:: prettypretty.fidelity
    :members:


prettypretty.style
------------------

.. automodule:: prettypretty.style
    :members:


prettypretty.terminal
---------------------

.. automodule:: prettypretty.terminal
    :members:
